module StaticUID
  class Million

    def self.generate(i)
      ensure_capacity!(i)

      lookup_table[i]
    end

    def self.capacity
      lookup_table.size
    end

    def self.fetch_lookup_table
      capacity
    end

    private

    def self.ensure_capacity!(i)
      if i >= capacity
        raise RuntimeError, "Capacity (#{capacity}) exceeded with #{i}"
      end
    end

    def self.lookup_table
      @lookup_table ||= build_lookup_table
    end

    def self.build_lookup_table
      File.open(lookup_table_file).to_a.map(&:strip)
    end

    def self.lookup_table_file
      File.expand_path File.join('..', 'lookup_tables', 'million'), __FILE__
    end
  end
end
